@@ -9,8 +9,11 @@ import pathlib
 import sys
 import textwrap
 
+from abc import abstractmethod
 from collections import defaultdict
-from collections.abc import Callable, Mapping
+from collections.abc import (
+    Awaitable, Callable, Iterator, Mapping,
+)
 from functools import partial
 from typing import (
     TYPE_CHECKING, Any, ClassVar, Literal,
@@ -23,6 +26,7 @@ from param.parameterized import ParameterizedMetaclass
 from .config import config
 from .io.datamodel import construct_data_model
 from .io.document import freeze_doc, hold
+from .io.model import apply_changes_without_dispatch
 from .io.resources import component_resource_path
 from .io.state import state
 from .layout.base import Panel
@@ -164,6 +168,9 @@ class PyComponent(Viewable, Layoutable):
             self._view__ = self._create__view()
         return super().select(selector) + self._view__.select(selector)
 
+    @abstractmethod
+    def __panel__(self) -> Viewable | Iterator[Viewable] | Awaitable[Viewable]:
+        raise NotImplementedError
 
 
 class ReactiveESMMetaclass(ReactiveMetaBase):
@@ -244,6 +251,8 @@ class ReactiveESM(ReactiveCustomBase, metaclass=ReactiveESMMetaclass):
 
     _importmap: ClassVar[dict[Literal['imports', 'scopes'], dict[str,str]]] = {}
 
+    _render_policy: Literal['manual', 'children'] = "children"
+
     __abstract = True
 
     def __init__(self, **params):
@@ -329,7 +338,7 @@ class ReactiveESM(ReactiveCustomBase, metaclass=ReactiveESMMetaclass):
 
     @classmethod
     def _esm_path(cls, compiled: bool | Literal['compiling'] = True) -> os.PathLike | None:
-        if compiled or not cls._esm:
+        if compiled is True or not cls._esm:
             bundle_path = cls._bundle_path
             if bundle_path:
                 return bundle_path
@@ -450,6 +459,7 @@ class ReactiveESM(ReactiveCustomBase, metaclass=ReactiveESMMetaclass):
             (p in Viewable.param and p not in ('name', 'use_shadow_dom')
              and type(Reactive.param[p]) is type(cls.param[p]))
         ]
+        events = []
         for k, v in self.param.values().items():
             p = self.param[k]
             if is_viewable_param(p) or type(self)._property_mapping.get(k, "") is None:
@@ -459,6 +469,8 @@ class ReactiveESM(ReactiveCustomBase, metaclass=ReactiveESMMetaclass):
                 continue
             if k in props:
                 props.pop(k)
+            if isinstance(p, param.Event):
+                events.append(k)
             data_params[k] = v
         bundle_path = self._bundle_path
         importmap = self._process_importmap()
@@ -484,7 +496,9 @@ class ReactiveESM(ReactiveCustomBase, metaclass=ReactiveESMMetaclass):
             'data': self._data_model(**{p: v for p, v in data_props.items() if p not in ignored}),
             'dev': config.autoreload or getattr(self, '_debug', False),
             'esm': self._render_esm(not config.autoreload, server=is_session),
+            'events': events,
             'importmap': importmap,
+            'render_policy': self._render_policy,
             'name': cls.__name__
         })
         return props
@@ -573,7 +587,7 @@ class ReactiveESM(ReactiveCustomBase, metaclass=ReactiveESMMetaclass):
         self, events: dict[str, param.parameterized.Event], msg: dict[str, Any],
         root: Model, model: Model, doc: Document, comm: Comm | None
     ) -> None:
-        model_msg, data_msg  = {}, {}
+        model_msg, data_msg, data_resets  = {}, {}, {}
         for prop, v in list(msg.items()):
             if prop in list(Reactive.param)+['esm', 'importmap']:
                 model_msg[prop] = v
@@ -581,6 +595,8 @@ class ReactiveESM(ReactiveCustomBase, metaclass=ReactiveESMMetaclass):
                 continue
             else:
                 data_msg[prop] = v
+                if prop in self.param and isinstance(self.param[prop], param.Event) and v:
+                    data_resets[prop] = False
         for name, event in events.items():
             if name not in model.children:
                 continue
@@ -597,7 +613,6 @@ class ReactiveESM(ReactiveCustomBase, metaclass=ReactiveESMMetaclass):
             data_msg.update(children)
             model_msg['children'] = list(children)
 
-
         ref = root.ref['id']
         prev_changing = self._changing.get(ref, [])
         try:
@@ -606,8 +621,10 @@ class ReactiveESM(ReactiveCustomBase, metaclass=ReactiveESMMetaclass):
             with hold(doc):
                 changing = []
                 with freeze_doc(doc, model, msg, force=update_children):
-                    changing += self._set_on_model(model_msg, root, model)
-                    changing += self._set_on_model(data_msg, root, model.data)
+                    if model_msg:
+                        changing += self._set_on_model(model_msg, root, model)
+                    if data_msg:
+                        changing += self._set_on_model(data_msg, root, model.data)
                     if update and update_children and ref in state._views:
                         state._views[ref][0]._preprocess(root, self, old_children)
                 self._changing[ref] = changing
@@ -617,6 +634,8 @@ class ReactiveESM(ReactiveCustomBase, metaclass=ReactiveESMMetaclass):
                 self._changing[ref] = prev_changing
             elif ref in self._changing:
                 del self._changing[ref]
+        if data_resets:
+            apply_changes_without_dispatch(doc, model.data, data_resets)
 
     def _handle_msg(self, data: Any) -> None:
         """
@@ -804,6 +823,8 @@ class ReactComponent(ReactiveESM):
 
     _react_version = '18.3.1'
 
+    _render_policy = "manual"
+
     @classproperty  # type: ignore
     def _exports__(cls) -> ExportSpec:  # type: ignore
         imports = cls._importmap.get('imports', {})
