@@ -2,13 +2,18 @@ from __future__ import annotations
 
 import base64
 import concurrent.futures
+import dataclasses
 import json
 import os
 import pathlib
 import uuid
 
 from collections.abc import Sequence
-from typing import IO, Any, Literal
+from typing import (
+    IO, Any, Literal, cast,
+)
+from urllib.parse import urlparse
+from zipfile import ZipFile
 
 import bokeh
 
@@ -20,6 +25,7 @@ from bokeh.embed.elements import script_for_render_items
 from bokeh.embed.util import RenderItem, standalone_docs_json_and_render_items
 from bokeh.embed.wrappers import wrap_in_script_tag
 from bokeh.util.serialization import make_id
+from packaging.requirements import Requirement
 
 from .. import __version__, config
 from ..util import base_version, escape
@@ -36,13 +42,13 @@ from .state import set_curdoc, state
 PWA_MANIFEST_TEMPLATE = _pn_env.get_template('site.webmanifest')
 SERVICE_WORKER_TEMPLATE = _pn_env.get_template('serviceWorker.js')
 WEB_WORKER_TEMPLATE = _pn_env.get_template('pyodide_worker.js')
-WORKER_HANDLER_TEMPLATE  = _pn_env.get_template('pyodide_handler.js')
+WORKER_HANDLER_TEMPLATE = _pn_env.get_template('pyodide_handler.js')
 
 PANEL_ROOT = pathlib.Path(__file__).parent.parent
 BOKEH_VERSION = base_version(bokeh.__version__)
 PY_VERSION = base_version(__version__)
-PYODIDE_VERSION = 'v0.27.5'
-PYSCRIPT_VERSION = '2025.2.1'
+PYODIDE_VERSION = 'v0.28.2'
+PYSCRIPT_VERSION = '2025.8.1'
 WHL_PATH = DIST_DIR / 'wheels'
 PANEL_LOCAL_WHL = WHL_PATH / f'panel-{__version__.replace("-dirty", "")}-py3-none-any.whl'
 BOKEH_LOCAL_WHL = WHL_PATH / f'bokeh-{BOKEH_VERSION}-py3-none-any.whl'
@@ -51,10 +57,10 @@ BOKEH_CDN_WHL = f'{CDN_ROOT}wheels/bokeh-{BOKEH_VERSION}-py3-none-any.whl'
 PYODIDE_URL = f'https://cdn.jsdelivr.net/pyodide/{PYODIDE_VERSION}/full/pyodide.js'
 PYODIDE_PYC_URL = f'https://cdn.jsdelivr.net/pyodide/{PYODIDE_VERSION}/pyc/pyodide.js'
 PYSCRIPT_CSS = f'<link rel="stylesheet" href="https://pyscript.net/releases/{PYSCRIPT_VERSION}/core.css" />'
-PYSCRIPT_CSS_OVERRIDES = f'<link rel="stylsheet" href="{CDN_DIST}css/pyscript.css" />'
-PYSCRIPT_JS = f'<script type="module" src="https://pyscript.net/releases/{PYSCRIPT_VERSION}/core.js"></script>'
-PYODIDE_JS = f'<script src="{PYODIDE_URL}"></script>'
-PYODIDE_PYC_JS = f'<script src="{PYODIDE_PYC_URL}"></script>'
+PYSCRIPT_CSS_OVERRIDES = f'<link rel="stylesheet" href="{CDN_DIST}css/pyscript.css" />'
+PYSCRIPT_JS = f'<script type="module" src="https://pyscript.net/releases/{PYSCRIPT_VERSION}/core.js" defer></script>'
+PYODIDE_JS = f'<script src="{PYODIDE_URL}" defer></script>'
+PYODIDE_PYC_JS = f'<script src="{PYODIDE_PYC_URL}" defer></script>'
 LOCAL_PREFIX = './'
 
 MINIMUM_VERSIONS: dict[str, str] = {}
@@ -90,6 +96,11 @@ PYODIDE_SCRIPT = """
 <script type="text/javascript">
 async function main() {
   let pyodide = await loadPyodide();
+  for (const archive of [{{ data_archives }}]) {
+    let zipResponse = await fetch(archive);
+    let zipBinary = await zipResponse.arrayBuffer();
+    await pyodide.unpackArchive(zipBinary, "zip");
+  }
   await pyodide.loadPackage("micropip");
   await pyodide.runPythonAsync(`
     import micropip
@@ -98,7 +109,14 @@ async function main() {
   code = `{{ code }}`
   await pyodide.runPythonAsync(code);
 }
-main();
+const run_main_on_load = () => {
+  if (typeof loadPyodide !== 'undefined') {
+    main();
+  } else {
+    setTimeout(run_main_on_load, 100);
+  }
+};
+run_main_on_load();
 </script>
 """
 
@@ -121,6 +139,13 @@ if ('serviceWorker' in navigator) {
 </script>
 """
 
+@dataclasses.dataclass
+class DummyRequirement:
+    url: str
+    name: str = 'DUMMY'
+    specifier: str = ''
+
+
 def make_index(files, title=None, manifest=True):
     if manifest:
         manifest = 'site.webmanifest'
@@ -147,9 +172,145 @@ def build_pwa_manifest(files, title=None, **kwargs) -> str:
         **kwargs
     )
 
+
+def collect_python_requirements(
+    code: str | os.PathLike | IO,
+    requirements: list[str] | Literal['auto'] | os.PathLike = 'auto',
+    panel_version: Literal['auto', 'local'] | str = 'auto',
+    http_patch: bool = True,
+) -> list[str]:
+    """
+    Make sense of python requirements for our Panel script.
+
+    Arguments
+    ---------
+    app: str | os.PathLike | IO,
+        The filename of the Panel/Bokeh application to convert.
+    requirements: list[str] | os.PathLike | Literal['auto']
+        The list of requirements to include (in addition to Panel).
+    panel_version: Literal['auto', 'local'] | str
+        The panel release version to use in the exported HTML.
+    http_patch: bool
+        Whether to patch the HTTP request stack with the pyodide-http library
+        to allow urllib3 and requests to work.
+    """
+    # Environment
+    if panel_version == 'local':
+        panel_req = './' + str(PANEL_LOCAL_WHL.as_posix()).split('/')[-1]
+        bokeh_req = './' + str(BOKEH_LOCAL_WHL.as_posix()).split('/')[-1]
+    elif panel_version == 'auto':
+        panel_req = PANEL_CDN_WHL
+        bokeh_req = BOKEH_CDN_WHL
+    else:
+        panel_req = f'panel=={panel_version}'
+        bokeh_req = f'bokeh=={BOKEH_VERSION}'
+    collected_requirements = [bokeh_req, panel_req]
+    if http_patch:
+        collected_requirements.append('pyodide-http')
+
+    requirements_root = os.getcwd()
+    resolved_reqs: list[str]
+    if requirements == 'auto':
+        if hasattr(code, 'read'):
+            source = code.read()
+        else:
+            path = pathlib.Path(code)
+            application = build_single_handler_application(path.absolute())
+            source = application._handlers[0]._runner.source
+        resolved_reqs = find_requirements(source)
+    elif isinstance(requirements, str) and pathlib.Path(requirements).is_file():
+        requirements_root = os.path.dirname(requirements)
+        resolved_reqs = (
+            pathlib.Path(requirements).read_text(encoding='utf-8').splitlines()
+        )
+    elif isinstance(requirements, list):
+        resolved_reqs = requirements
+    else:
+        raise ValueError(
+            f'Requirements {requirements!r} could not be resolved. '
+            'Provide a list of requirement specs, a path to a requirements.txt '
+            'file that exists on disk or \'auto\' as a literal.'
+        )
+
+    for raw_req in resolved_reqs:
+        stripped_req = raw_req.split('#')[0].strip()
+        if not len(stripped_req) > 0:
+            continue
+        try:
+            req = Requirement(stripped_req)
+        except ValueError as e:
+            if stripped_req.endswith('.whl'):
+                req = cast(Requirement, DummyRequirement(stripped_req))
+            else:
+                raise ValueError(f'Requirements parser raised following error: {e}') from e
+
+        if req.name in ('panel', 'bokeh'):
+            continue
+        elif req.url is not None:
+            parsed_req = urlparse(req.url)
+            if parsed_req.scheme in ('https', 'http'):
+                collected_requirements.append(req.url)
+            elif parsed_req.scheme in ('file', ''):
+                check_path = parsed_req.path
+                check_path = os.path.normpath(
+                    os.path.join(requirements_root, check_path)
+                )
+                if os.path.exists(check_path):
+                    collected_requirements.append(
+                        f'file:{check_path}'
+                    )  # make a custom URL so things can be handled as a URL
+                else:
+                    raise ValueError(f'Could not verify path for {req}. Make sure the file is available if it is a local wheel.')
+        else:
+            collected_requirements.append(f'{req.name}{req.specifier}')
+
+    return collected_requirements
+
+
+def pack_files(filemap: dict, destination: str | os.PathLike | IO):
+    """
+    Pack files into a zipfile for distribution
+
+    Arguments
+    ---------
+    filemap: dict
+        A dictionary mapping a local file to an archive name
+    destination: str | os.PathLike | IO
+        where to put the output zip
+    """
+    with ZipFile(destination, 'w') as packfile:
+        for fname, arcname in filemap.items():
+            packfile.write(fname, arcname=arcname)
+
+
+def loading_resources(template, inline) -> list[str]:
+    css_resources = []
+    if template in (BASE_TEMPLATE, FILE):
+        # Add loading.css if not served from Panel template
+        if inline:
+            svg_name = f'{config.loading_spinner}_spinner.svg'
+            svg_b64 = base64.b64encode((DIST_DIR / 'assets' / svg_name).read_bytes()).decode('utf-8')
+            loading_base = (
+                DIST_DIR / "css" / "loading.css"
+            ).read_text(encoding='utf-8').replace(
+                f'../assets/{svg_name}', f'data:image/svg+xml;base64,{svg_b64}'
+            )
+            loading_style = f'<style type="text/css">\n{loading_base}\n</style>'
+        else:
+            loading_style = f'<link rel="stylesheet" href="{CDN_DIST}css/loading.css" type="text/css" />'
+        css_resources.append(loading_style)
+    spinner_css = loading_css(
+        config.loading_spinner, config.loading_color, config.loading_max_height
+    )
+    css_resources.append(
+        f'<style type="text/css">\n{spinner_css}\n</style>'
+    )
+    return css_resources
+
 def script_to_html(
     filename: str | os.PathLike | IO,
-    requirements: list[str] | Literal['auto'] | os.PathLike = 'auto',
+    requirements: list[str] = [],
+    app_resources: str | os.PathLike | None = None,
     js_resources: Literal['auto'] | list[str] = 'auto',
     css_resources: Literal['auto'] | list[str] | None = 'auto',
     runtime: Runtimes = 'pyodide',
@@ -157,7 +318,6 @@ def script_to_html(
     panel_version: Literal['auto', 'local'] | str = 'auto',
     local_prefix: str = LOCAL_PREFIX,
     manifest: str | None = None,
-    http_patch: bool = True,
     inline: bool = False,
     compiled: bool = True
 ) -> tuple[str, str | None]:
@@ -169,23 +329,22 @@ def script_to_html(
     ----------
     filename: str | Path | IO
         The filename of the Panel/Bokeh application to convert.
-    requirements: 'auto' | List[str] | os.PathLike
-        The list of requirements to include (in addition to Panel).
-    js_resources: 'auto' | List[str]
+    requirements: list[str]
+        The preprocessed, micropip-compatible list of requirements to include.
+    app_resources: os.PathLike
+        relative path of zip with data to extract
+    js_resources: 'auto' | list[str]
         The list of JS resources to include in the exported HTML.
-    css_resources: 'auto' | List[str] | None
+    css_resources: 'auto' | list[str] | None
         The list of CSS resources to include in the exported HTML.
     runtime: 'pyodide' | 'pyscript'
         The runtime to use for running Python in the browser.
     prerender: bool
         Whether to pre-render the components so the page loads.
-    panel_version: 'auto' | str
+    panel_version: Literal['auto', 'local'] | str
         The panel release version to use in the exported HTML.
     local_prefix: str
         Prefix for the path to serve local wheel files from.
-    http_patch: bool
-        Whether to patch the HTTP request stack with the pyodide-http library
-        to allow urllib3 and requests to work.
     inline: bool
         Whether to inline resources.
     compiled: bool
@@ -214,46 +373,6 @@ def script_to_html(
             'the bokeh document manually.'
         )
 
-    if requirements == 'auto':
-        requirement_list = find_requirements(source)
-    elif isinstance(requirements, (str, os.PathLike)) and pathlib.Path(requirements).is_file():
-        requirement_list = pathlib.Path(requirements).read_text(encoding='utf-8').splitlines()
-        try:
-            from packaging.requirements import Requirement
-            requirement_list = [
-                r2 for r in requirement_list
-                if (r2 := r.split("#")[0].strip()) and Requirement(r2)
-            ]
-        except Exception as e:
-            raise ValueError(
-                f'Requirements parser raised following error: {e}'
-            ) from e
-    elif isinstance(requirements, list):
-        requirement_list = requirements
-    else:
-        raise ValueError(f'Could not resolve requirements file {requirements}')
-
-    # Environment
-    if panel_version == 'local':
-        panel_req = local_prefix + str(PANEL_LOCAL_WHL.as_posix()).split('/')[-1]
-        bokeh_req = local_prefix + str(BOKEH_LOCAL_WHL.as_posix()).split('/')[-1]
-    elif panel_version == 'auto':
-        panel_req = PANEL_CDN_WHL
-        bokeh_req = BOKEH_CDN_WHL
-    else:
-        panel_req = f'panel=={panel_version}'
-        bokeh_req = f'bokeh=={BOKEH_VERSION}'
-
-    base_reqs = [bokeh_req, panel_req]
-    if http_patch:
-        base_reqs.append('pyodide-http==0.2.1')
-    reqs = base_reqs + [
-        req for req in requirement_list if req not in ('panel', 'bokeh')
-    ]
-    for name, min_version in MINIMUM_VERSIONS.items():
-        if any(name in req for req in reqs):
-            reqs = [f'{name}>={min_version}' if name in req else req for req in reqs]
-
     # Execution
     post_code = POST_PYSCRIPT if runtime == 'pyscript' else POST
     code = '\n'.join([PRE, source, post_code])
@@ -267,7 +386,12 @@ def script_to_html(
             css_resources = [PYSCRIPT_CSS, PYSCRIPT_CSS_OVERRIDES]
         elif not css_resources:
             css_resources = []
-        pyconfig = json.dumps({'packages': reqs})
+        pyconfig = json.dumps({
+            'packages': requirements,
+            'plugins': ['!error'],
+            'files': {app_resources: './*'} if app_resources else {},
+        })
+        css_resources.append('<style type="text/css">.py-error { display: none; }</style>')
         if 'worker' in runtime:
             plot_script = f'<script type="py" async worker config=\'{pyconfig}\' src="{app_name}.py"></script>'
             web_worker = code
@@ -276,8 +400,9 @@ def script_to_html(
     else:
         if css_resources == 'auto':
             css_resources = []
-        env_spec = ', '.join([repr(req) for req in reqs])
-        code = code.encode("unicode_escape").decode("utf-8").replace('`', r'\`')
+        data_archives = f'{repr(app_resources)}' if app_resources else ''
+        env_spec = ', '.join([repr(req) for req in requirements])
+        code = code.encode('unicode_escape').decode('utf-8').replace('`', r'\`')
         if runtime == 'pyodide-worker':
             if js_resources == 'auto':
                 js_resources = []
@@ -287,6 +412,7 @@ def script_to_html(
             })
             web_worker = WEB_WORKER_TEMPLATE.render({
                 'PYODIDE_URL': PYODIDE_PYC_URL if compiled else PYODIDE_URL,
+                'data_archives': data_archives,
                 'env_spec': env_spec,
                 'code': code
             })
@@ -296,6 +422,7 @@ def script_to_html(
                 js_resources = [PYODIDE_PYC_JS if compiled else PYODIDE_JS]
             script_template = _pn_env.from_string(PYODIDE_SCRIPT)
             plot_script = script_template.render({
+                'data_archives': data_archives,
                 'env_spec': env_spec,
                 'code': code
             })
@@ -309,9 +436,9 @@ def script_to_html(
         plot_script += wrap_in_script_tag(script_for_render_items(json_id, render_items))
     else:
         render_item = RenderItem(
-            token = '',
-            roots = document.roots,
-            use_for_title = False
+            token='',
+            roots=document.roots,
+            use_for_title=False
         )
         render_items = [render_item]
 
@@ -324,26 +451,7 @@ def script_to_html(
 
     # Collect resources
     resources = Resources(mode='inline' if inline else 'cdn')
-    if template in (BASE_TEMPLATE, FILE):
-        # Add loading.css if not served from Panel template
-        if inline:
-            svg_name = f'{config.loading_spinner}_spinner.svg'
-            svg_b64 = base64.b64encode((DIST_DIR / 'assets' / svg_name).read_bytes()).decode('utf-8')
-            loading_base = (
-                DIST_DIR / "css" / "loading.css"
-            ).read_text(encoding='utf-8').replace(
-                f'../assets/{svg_name}', f'data:image/svg+xml;base64,{svg_b64}'
-            )
-            loading_style = f'<style type="text/css">\n{loading_base}\n</style>'
-        else:
-            loading_style = f'<link rel="stylesheet" href="{CDN_DIST}css/loading.css" type="text/css" />'
-        css_resources.append(loading_style)
-    spinner_css = loading_css(
-        config.loading_spinner, config.loading_color, config.loading_max_height
-    )
-    css_resources.append(
-        f'<style type="text/css">\n{spinner_css}\n.py-error {{ display: none; }}</style>'
-    )
+    css_resources += loading_resources(template, inline)
     with set_curdoc(document):
         bokeh_js, bokeh_css = bundle_resources(document.roots, resources)
     extra_js = [INIT_SERVICE_WORKER, bokeh_js] if manifest else [bokeh_js]
@@ -386,6 +494,7 @@ def convert_app(
     app: str | os.PathLike,
     dest_path: str | os.PathLike | None = None,
     requirements: list[str] | Literal['auto'] | os.PathLike = 'auto',
+    resources: list[str] | list[os.PathLike] | None = None,
     runtime: Runtimes = 'pyodide-worker',
     prerender: bool = True,
     manifest: str | None = None,
@@ -401,31 +510,87 @@ def convert_app(
     elif not isinstance(dest_path, pathlib.PurePath):
         dest_path = pathlib.Path(dest_path)
 
+    app_folder = os.path.dirname(app)
+    app_name = '.'.join(os.path.basename(app).split('.')[:-1])
+
+    # Obtain source
+    parsed_requirements = collect_python_requirements(
+        app, requirements, panel_version=panel_version, http_patch=http_patch
+    )
+    # prepare wheels to be available via emscripten MEMFS
+    parsed_requirements_rewritten = []
+    wheels2pack: dict[str | os.PathLike, str] = {}
+
+    for req in parsed_requirements:
+        try:
+            req_as_url = urlparse(req)
+            if req_as_url.scheme == 'file':
+                wheel_name = os.path.basename(req_as_url.path)
+                emfs_wheel_path = 'packed_wheels' + '/' + wheel_name
+                parsed_requirements_rewritten.append(f'emfs:{emfs_wheel_path}')
+                wheels2pack[req_as_url.path] = emfs_wheel_path
+            else:
+                parsed_requirements_rewritten.append(req)
+        except ValueError:
+            # no url, so must be a properly formatted requirement
+            parsed_requirements_rewritten.append(req)
+
+    # make a zip out of resources
+    resources_validated: dict[str | os.PathLike, str] = {}
+    for resourcepath in ([] if resources is None else resources):
+        commonpath = pathlib.Path(
+            os.path.commonpath(
+                [os.path.abspath(resourcepath), os.path.abspath(app_folder)]
+            )
+        )
+        if commonpath.resolve() == pathlib.Path(app_folder).resolve():
+            resources_validated[resourcepath] = os.path.relpath(
+                resourcepath, app_folder
+            )
+        else:
+            raise ValueError('resources have to be in a folder rootable at the app-directory')
+
+    # resources unpacked into emscripten MEMFS
+    app_resources = {**wheels2pack, **resources_validated}
+    if app_resources:
+        app_resources_packfile = f'{app_name}.resources.zip'
+        pack_files(app_resources, os.path.join(dest_path, app_resources_packfile))
+    else:
+        app_resources_packfile = None
+
+    # try to convert the app to a standalone package
     try:
         with set_resource_mode('inline' if inline else 'cdn'):
             html, worker = script_to_html(
-                app, requirements=requirements, runtime=runtime,
-                prerender=prerender, manifest=manifest,
-                panel_version=panel_version, http_patch=http_patch,
-                inline=inline, compiled=compiled, local_prefix=local_prefix
+                app,
+                requirements=parsed_requirements_rewritten,
+                app_resources=app_resources_packfile,
+                runtime=runtime,
+                prerender=prerender,
+                manifest=manifest,
+                panel_version=panel_version,
+                inline=inline,
+                compiled=compiled,
+                local_prefix=local_prefix
             )
     except KeyboardInterrupt:
         return
     except Exception as e:
         print(f'Failed to convert {app} to {runtime} target: {e}')
         return
-    name = '.'.join(os.path.basename(app).split('.')[:-1])
-    filename = f'{name}.html'
 
-    with open(dest_path / filename, 'w', encoding="utf-8") as out:
+    # write out the app
+    filename = f'{app_name}.html'
+
+    with open(dest_path / filename, 'w', encoding='utf-8') as out:
         out.write(html)
     if 'worker' in runtime and worker:
         ext = 'py' if runtime.startswith('pyscript') else 'js'
-        with open(dest_path / f'{name}.{ext}', 'w', encoding="utf-8") as out:
+        with open(dest_path / f'{app_name}.{ext}', 'w', encoding="utf-8") as out:
             out.write(worker)
     if verbose:
         print(f'Successfully converted {app} to {runtime} target and wrote output to {filename}.')
-    return (name.replace('_', ' '), filename)
+    return (app_name.replace('_', ' '), filename)
 
 
 def _convert_process_pool(
@@ -443,7 +608,7 @@ def _convert_process_pool(
     groups = [apps[i:i+max_workers] for i in range(0, len(apps), max_workers)]
     for group in groups:
         with ProcessPoolExecutor(
-                max_workers=max_workers, mp_context=mp.get_context('spawn')
+            max_workers=max_workers, mp_context=mp.get_context('spawn')
         ) as executor:
             futures = []
             for app in group:
@@ -462,12 +627,14 @@ def _convert_process_pool(
                     files[name] = filename
     return files
 
+
 def convert_apps(
     apps: str | os.PathLike | Sequence[str | os.PathLike],
     dest_path: str | os.PathLike | None = None,
     title: str | None = None,
     runtime: Runtimes = 'pyodide-worker',
     requirements: list[str] | Literal['auto'] | os.PathLike = 'auto',
+    resources: list[str] | list[os.PathLike] | None = None,
     prerender: bool = True,
     build_index: bool = True,
     build_pwa: bool = True,
@@ -512,7 +679,7 @@ def convert_apps(
           - theme_color: The theme color of the application
     max_workers: int
         The maximum number of parallel workers
-    panel_version: 'auto' | 'local'] | str
+    panel_version: Literal['auto' | 'local'] | str
 '       The panel version to include.
     local_prefix: str
         Prefix for the path to serve local wheel files from.
@@ -546,6 +713,8 @@ def convert_apps(
         app_requirements = requirements
 
     kwargs = {
+        'requirements': app_requirements,
+        'resources': resources if resources else [],
         'runtime': runtime,
         'prerender': prerender,
         'manifest': manifest,
@@ -559,12 +728,12 @@ def convert_apps(
 
     if state._is_pyodide:
         files = {
-            app: convert_app(app, dest_path, requirements=app_requirements, **kwargs)  # type: ignore
+            app: convert_app(app, dest_path, **kwargs)  # type: ignore
             for app in apps
         }
     else:
         files = _convert_process_pool(
-            apps, dest_path, max_workers=max_workers, requirements=app_requirements, **kwargs
+            apps, dest_path, max_workers=max_workers, **kwargs  # type: ignore
         )
 
     if build_index and len(files) >= 1:
@@ -590,7 +759,7 @@ def convert_apps(
 
     # Write manifest
     manifest = build_pwa_manifest(files, title=title, **pwa_config)
-    with open(dest_path / 'site.webmanifest', 'w', encoding="utf-8") as f:
+    with open(dest_path / 'site.webmanifest', 'w', encoding='utf-8') as f:
         f.write(manifest)
     if verbose:
         print('Successfully wrote site.manifest.')
@@ -601,7 +770,7 @@ def convert_apps(
         name=title or 'Panel Pyodide App',
         pre_cache=', '.join([repr(p) for p in img_rel])
     )
-    with open(dest_path / 'serviceWorker.js', 'w', encoding="utf-8") as f:
+    with open(dest_path / 'serviceWorker.js', 'w', encoding='utf-8') as f:
         f.write(worker)
     if verbose:
         print('Successfully wrote serviceWorker.js.')
