@@ -66,19 +66,19 @@ class Player(Widget):
     show_value = Bool(True, help="""
         Whether to show the widget value""")
 
-    width = Override(default=400)
+    width = Override(default=400)  # type: ignore
 
-    height = Override(default=250)
+    height = Override(default=250)  # type: ignore
 
     scale_buttons = Float(1, help="Percentage to scale the size of the buttons by")
 
     visible_buttons = List(String, default=[
         'slower', 'first', 'previous', 'reverse', 'pause', 'play', 'next', 'last', 'faster'
-    ], help="The buttons to display on the player.")
+    ], help="The buttons to display on the player.")  # type: ignore
 
     visible_loop_options = List(String, default=[
         'once', 'loop', 'reflect'
-    ], help="The loop options to display on the player.")
+    ], help="The loop options to display on the player.")  # type: ignore
 
 class DiscretePlayer(Player):
 
@@ -167,9 +167,9 @@ class VideoStream(HTMLBox):
 
     value = Any(help="""Snapshot Data""")
 
-    height = Override(default=240)
+    height = Override(default=240)  # type: ignore
 
-    width = Override(default=320)
+    width = Override(default=320)  # type: ignore
 
 
 class Progress(HTMLBox):
@@ -216,7 +216,7 @@ class FileDownload(InputWidget):
     A private property to create and click the link.
     """)
 
-    title = Override(default='')
+    title = Override(default='')  # type: ignore
 
 
 class CustomSelect(Select):
