@@ -1,15 +1,15 @@
 import pytest
 
-try:
-    from playwright.sync_api import expect
-    pytestmark = pytest.mark.ui
-except ImportError:
-    pytestmark = pytest.mark.skip('playwright not available')
+pytest.importorskip("playwright")
+
+from playwright.sync_api import expect
 
 from panel.pane import Markdown
 from panel.template import FastGridTemplate
 from panel.tests.util import serve_component
 
+pytestmark = pytest.mark.ui
+
 
 def test_fast_grid_template_no_console_errors(page):
     tmpl = FastGridTemplate()
