@@ -161,6 +161,9 @@ def wait_until(fn, page=None, timeout=5000, interval=100):
     # Hide this function traceback from the pytest output if the test fails
     __tracebackhide__ = True
 
+    if page:
+        page.wait_for_load_state('networkidle')
+
     start = time.time()
 
     def timed_out():
@@ -230,6 +233,9 @@ async def async_wait_until(fn, page=None, timeout=5000, interval=100):
     # Hide this function traceback from the pytest output if the test fails
     __tracebackhide__ = True
 
+    if page:
+        await page.wait_for_load_state('networkidle')
+
     start = time.time()
 
     def timed_out():
@@ -315,6 +321,7 @@ def serve_and_wait(app, page=None, prefix=None, port=None, proxy=None, **kwargs)
     wait_for_server(port, prefix=prefix)
     if page:
         page.wait_for_function("document.readyState === 'complete'", timeout=5000)
+        page.wait_for_load_state('networkidle')
     return port
 
 serve_and_wait.server_implementation = 'tornado'
@@ -330,6 +337,7 @@ def serve_component(page, app, suffix='', wait=True, **kwargs):
 
     if page and wait:
         page.wait_for_function("document.readyState === 'complete'", timeout=5000)
+        page.wait_for_load_state('networkidle')
     return msgs, port
 
 
