@@ -49,7 +49,8 @@ if TYPE_CHECKING:
 
 class SelectBase(Widget):
 
-    options = param.ClassSelector(default=[], class_=(dict, list))
+    options = param.ClassSelector(default=[], class_=(dict, list), doc="""
+        A list or dictionary of options to select from.""")
 
     __abstract = True
 
@@ -179,7 +180,7 @@ class Select(SingleSelectBase):
     """
 
     description = param.String(default=None, doc="""
-        An HTML string describing the function of this component.""")
+        A description of the widget, which will be displayed as a tooltip.""")
 
     disabled_options = param.List(default=[], nested_refs=True, doc="""
         Optional list of ``options`` that are disabled, i.e. unusable and
